@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# $Id: owfs.py 1595 2016-11-27 18:01:54Z mwall $
+# $Id: owfs.py 1676 2017-03-03 22:52:56Z mwall $
 #
 # Copyright 2013 Matthew Wall
 # Thanks to Mark Cressey (onewireweewx) and Howard Walter (TAI code).
@@ -170,7 +170,7 @@ from weewx.drivers import AbstractDevice
 from weewx.engine import StdService
 
 DRIVER_NAME = 'OWFS'
-DRIVER_VERSION = "0.19"
+DRIVER_VERSION = "0.20"
 
 def logmsg(level, msg):
     syslog.syslog(level, 'owfs: %s' % msg)
@@ -445,15 +445,9 @@ class OWFSDriver(weewx.drivers.AbstractDevice):
                 else:
                     logerr("unknown sensor type '%s' for %s" % (st, s))
             self.last_data.update(last_data)
-            self.calculate_derived(p)
             yield p
             time.sleep(self.polling_interval)
 
-    def calculate_derived(self, data):
-        if 'windSpeed' in data:
-            if data['windSpeed'] is None or data['windSpeed'] == 0:
-                data['windDir'] = None
-
 class OWFSService(weewx.engine.StdService):
     """Collect data from one-wire devices via owfs."""
 
